@@ -1,4 +1,4 @@
 from ttag.tests.main import TagExecutionTests, TestArgumentTypes, \
     PositionalTest, KeywordsArgTest
 from ttag.tests.registration import RegisterTest
-from ttag.tests.helpers import AsTag
+from ttag.tests.helpers import AsTag, TemplateTag
